#!/bin/sh

usage() {
    echo -e -n "\n"
    echo "Usage: perfDWTool.sh [options...] <command>"
    echo -e -n "\n"
    echo "Options:"
    echo "    -?, -help                             print this message"
    echo "    -u <username>, -username <username>   user name of the performance DW user"
    echo "    -p <password>, -password <password>   user password (unencrypted)"
    echo "    -profileName <name>                   profile name"
    echo "    -nodeName <name>                      node name in an ND Environment"
    echo "    -serverName <name>                    server name in an ND Environment"
    echo -e -n "\n"
    echo "Commands:"
    echo " pending [schema-command-args] [-groups tracking-group-name-1 tracking-group-name-2 ...]"
    echo " archive [snapshot-id-1 snapshot-id-2 ...]"
    echo " restore [snapshot-id-1 snapshot-id-2 ...]"
    echo -e -n "\n"
    echo "Schema Command Args:"
    echo " -preview output-file-name"
    echo " -prepare output-file-name"
    echo " -execute"
    echo -e -n "\n"
    exit $1
}
CURR_PROFILE_BIN_DIR=pwd
CURR_PDW_TOOL_DIR=`dirname ${0}`

BIN_DIR=`dirname ${0}`/../../../../bin
cd $CURR_PROFILE_BIN_DIR
. ./setupCmdLine.sh
cd $CURR_PDW_TOOL_DIR

if [ -f ${JAVA_HOME}/bin/java ]; then
  JAVA_EXE="${JAVA_HOME}/bin/java"
else
  JAVA_EXE="${JAVA_HOME}/jre/bin/java"
fi

WASHOME_ARG="-DWAS_HOME=$WAS_HOME"
NODENAME_ARG=
SERVERNAME_ARG=
USERNAME_ARG=
PASSWORD_ARG=
LOGGING_ARG="-Djava.util.logging.config.file=logging.properties -Dtw.log4j.init=false"
ANT_ARGS="-e -logger com.lombardisoftware.tools.tracking.ant.ToolLogger"


FINISHED='0'
until [ "$#" = "0" -o $FINISHED = '1' ]
do
    case "$1" in
        '-help'|'-?')
            usage 0
            ;;
        '-USER_INSTALL_ROOT')
            USER_INSTALL_ROOT_ARG="$2"
            shift;shift
            ;;
        '-username'|'-u')
            USERNAME_ARG="-Dusername=$2"
            shift;shift
            ;;
        '-password'|'-p')
            PASSWORD_ARG="-Dpassword=$2"
            shift;shift
            ;;
        '-nodeName')
            NODENAME_ARG="-DnodeName=$2"
            shift;shift
            ;;
        '-serverName')
            SERVERNAME_ARG="-DserverName=$2"
            shift;shift
            ;;
        *)
            FINISHED='1'
            ;;
    esac
done

PROFILEPATH_ARG="-DprofilePath=$USER_INSTALL_ROOT_ARG"

COMMAND="$*"

if [ ! "$1" ]
then
    usage 1
fi

COMMAND_ARG="-Dcommand.line.args=\"$COMMAND\""

CLASSPATH=$CURR_PDW_TOOL_DIR
CLASSPATH=$CLASSPATH:$CURR_PDW_TOOL_DIR/resources
CLASSPATH=$CLASSPATH:$CURR_PDW_TOOL_DIR/lib/ant.jar
CLASSPATH=$CLASSPATH:$CURR_PDW_TOOL_DIR/lib/ant-launcher.jar
CLASSPATH=$CLASSPATH:$CURR_PDW_TOOL_DIR/lib/ant-nodeps.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/BPM/Lombardi/lib/ant-contrib.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/BPM/Lombardi/lib/twant.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/BPM/Lombardi/lib/commons-logging.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/BPM/Lombardi/lib/twperfsvrtool.jar

$JAVA_EXE -cp $CLASSPATH $WASHOME_ARG $PROFILEPATH_ARG $NODENAME_ARG $SERVERNAME_ARG $LOGGING_ARG -DtoolPath=${CURR_PDW_TOOL_DIR} $USERNAME_ARG $PASSWORD_ARG "${COMMAND_ARG}" org.apache.tools.ant.Main $ANT_ARGS -f $CURR_PDW_TOOL_DIR/perfDWTool.ant execute -verbose

if [ "$?" -ne "0" ]
then
    echo "Failed, please see logs for further details."
    echo -e -n "\n"
    exit $?
fi
