#!/bin/sh

usage() {
    echo -e -n "\n"
    echo "Usage: installProcessAppPackage.sh [options...] <package name> <username of the process server administrator> <user password>" 
    echo -e -n "\n"
    echo "Options:"
    echo "    -?, -help                             print this message"
    echo "    -h <host>, -host <host>               host of the process server where to deploy the package, required parameter in ND Environment"
    echo "    -t <port>, -port <port>               port of the process server where to deploy the package, required parameter in ND Environment"
    echo "    -profileName <name>                   profile name"
    echo "    -nodeName <name>                      node name, required parameter in ND Environment"
    echo "    -serverName <name>                    server name, required parameter in ND Environment"
    echo -e -n "\n"
    exit $1
}

if [  "$1" = "" -o "$1" = "-help" -o "$1" = "-?" ]; then
   usage 1
fi

TOOL_DIR=`dirname ${0}`

PARAMETER=
FILE=
 
FINISHED='0'
until [ "$#" = "1" -o "$#" = "0" -o $FINISHED = '1' ]
do
    case "$1" in
        '-help'|'-?')
            usage 1
            ;;
        '-branch')
            PARAMETER="$PARAMETER $1 $2"
            shift;shift
            ;;
        '-host'|'-h')
            PARAMETER="$PARAMETER $1 $2"
            shift;shift
            ;;
        '-port'|'-t')
            PARAMETER="$PARAMETER $1 $2"
            shift;shift
            ;;
        '-profileName')
            PARAMETER="$PARAMETER $1 $2"
            shift;shift
            ;;
        '-nodeName')
            PARAMETER="$PARAMETER $1 $2"
            shift;shift
            ;;
        '-serverName')
            PARAMETER="$PARAMETER $1 $2"
            shift;shift
            ;;
        *)
            FINISHED='1'
            ;;
  esac
done

if [ ! "$1" ]
then
    echo -e -n "\n"
    echo "Package is missing."
    echo -e -n "\n"
    usage 1
fi

if [ ! "$2" ]
then
    echo -e -n "\n"
    echo "Username is missing."
    echo -e -n "\n"
    usage 1
fi

if [ ! "$3" ]
then
    echo -e -n "\n"
    echo "Password is missing."
    echo -e -n "\n"
    usage 1
fi

PLATFORM=`/bin/uname`

if [ "$PLATFORM" = "AIX" ]; then 
	FILE="$(cd $(dirname $1); pwd)/$(basename $1)"
else
	FILE="$1"
fi

echo "Installing package  started ..."
echo "    Importing package  started ..." 
eval "$TOOL_DIR/_internalInstallPackage.sh $PARAMETER -username $2 -password $3 $FILE PackageInstalled"
if [ "$?" != "0" ]; then
    echo "    Importing package failed ..."
    exit 1
fi
echo "    Importing package  finished ..."
echo "    Executing custom pre-install task started ..." 
eval "$TOOL_DIR/customProcessAppPreInstall.sh $PARAMETER -username $2 -password $3 $FILE"
if [ "$?" != "0" ]; then
    echo "    Executing custom pre-install task failed ..."
    exit 1
fi
echo "    Executing custom pre-install task finished ..."
echo "    Executing installation service for package started ..." 
eval "$TOOL_DIR/_internalInstallPackage.sh $PARAMETER -username $2 -password $3 $FILE InstallationServiceExecuted"
if [ "$?" != "0" ]; then
    echo "    Executing installation service for package failed ..."
    exit 1
fi
echo "    Executing installation service for package finished ..."
echo "    Migrating global data for package started ..."
eval "$TOOL_DIR/_internalInstallPackage.sh $PARAMETER -username $2 -password $3 $FILE GlobalAssetMigrated"
if [ "$?" != "0" ]; then
    echo "    Migrating global data for package failed ..."
    exit 1
fi
echo "    Migrating global data for package finished ..."
echo "    Migrating in-flight instances for package started ..."
eval "$TOOL_DIR/_internalInstallPackage.sh $PARAMETER -username $2 -password $3 $FILE InstancedMigrated"
if [ "$?" != "0" ]; then
    echo "    Migrating in-flight instances for package failed ..."
    exit 1
fi
echo "    Migrating in-flight instances for package finished ..."
echo "    Package has been successfully installed."
